X-Original-To: pgsql-hackers-postgresql.org@postgresql.org Received: from localhost (mx1.hub.org [200.46.208.251]) by postgresql.org (Postfix) with ESMTP id B09D59FA5BE for ; Thu, 15 Jun 2006 17:29:50 -0300 (ADT) Received: from postgresql.org ([200.46.204.71]) by localhost (mx1.hub.org [200.46.208.251]) (amavisd-new, port 10024) with ESMTP id 45703-10 for ; Thu, 15 Jun 2006 17:29:42 -0300 (ADT) X-Greylist: from auto-whitelisted by SQLgrey- Received: from cronos.madness.at (madness.at [217.196.146.217]) by postgresql.org (Postfix) with ESMTP id DC52F9FA13E for ; Thu, 15 Jun 2006 17:29:42 -0300 (ADT) Received: from mastermind.kaltenbrunner.cc ([83.215.233.60]) by cronos.madness.at with esmtpsa (TLSv1:AES256-SHA:256) (Exim 4.62 (FreeBSD)) (envelope-from ) id 1FqyTA-0000S0-8D; Thu, 15 Jun 2006 22:29:40 +0200 Message-ID: <4491C330.5020104@kaltenbrunner.cc> Date: Thu, 15 Jun 2006 22:29:36 +0200 From: Stefan Kaltenbrunner User-Agent: Thunderbird 1.5.0.2 (X11/20060516) MIME-Version: 1.0 To: Bruce Momjian CC: pgsql-hackers@postgreSQL.org Subject: Re: Test request for Stats collector performance improvement References: <200606150405.k5F45cH11445@candle.pha.pa.us> In-Reply-To: <200606150405.k5F45cH11445@candle.pha.pa.us> X-Enigmail-Version: 0.94.0.0 Content-Type: text/plain; charset=ISO-8859-1 Content-Transfer-Encoding: 7bit X-Virus-Scanned: Maia Mailguard 1.0.1 X-Archive-Number: 200606/760 X-Sequence-Number: 84993 Bruce Momjian wrote: > Would some people please run the attached test procedure and report back > the results? I basically need to know the patch is an improvement on > more platforms than just my own. Thanks Debian Sarge/AMD64 Kernel 2.6.16.16 (all tests done multiple times with variation of less then 10%): -HEAD: real 0m0.486s user 0m0.064s sys 0m0.048s -HEAD with 100000 "SELECT 1;" queries: real 0m4.763s user 0m0.896s sys 0m1.232s -HEAD + stats: real 0m0.720s user 0m0.128s sys 0m0.096s -HEAD + stats (100k): real 0m7.204s user 0m1.504s sys 0m1.028s -HEAD + stats + patch: there is something weird going on here - I get either runtimes like: real 0m0.729s user 0m0.092s sys 0m0.100s and occasionally: real 0m3.926s user 0m0.144s sys 0m0.140s (always ~0,7 vs ~4 seconds - same variation as Qingqing Zhou seems to see) -HEAD + stats + patch(100k): similiar variation with: real 0m7.955s user 0m1.124s sys 0m1.164s and real 0m11.836s user 0m1.368s sys 0m1.156s (ie 7-8 seconds vs 11-12 seconds) looks like this patch is actually a loss on that box. Stefan